<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs" sourcelanguage="en_GB">
<context>
    <name>ComputerItemDelegate</name>
    <message>
        <location filename="computer-view/computer-item-delegate.cpp" line="155"/>
        <source>You should mount volume first</source>
        <translation>Svazek je třeba nejprve připojit (mount)</translation>
    </message>
</context>
<context>
    <name>ComputerNetworkItem</name>
    <message>
        <location filename="computer-view/computer-network-item.cpp" line="45"/>
        <source>Network Neighborhood</source>
        <translation>Okolní počítače</translation>
    </message>
</context>
<context>
    <name>ComputerRemoteVolumeItem</name>
    <message>
        <location filename="computer-view/computer-remote-volume-item.cpp" line="56"/>
        <source>Remote</source>
        <translation>Vzdálené</translation>
    </message>
</context>
<context>
    <name>ComputerUserShareItem</name>
    <message>
        <location filename="computer-view/computer-user-share-item.cpp" line="16"/>
        <source>User Share</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ComputerVolumeItem</name>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="49"/>
        <source>Volume</source>
        <translation>Svazek</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="58"/>
        <location filename="computer-view/computer-volume-item.cpp" line="98"/>
        <source>File System</source>
        <translation>Souborový systém</translation>
    </message>
</context>
<context>
    <name>LoginRemoteFilesystem</name>
    <message>
        <location filename="login-remote-filesystem.ui" line="41"/>
        <source>Connect to Sever</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="89"/>
        <source>server information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="111"/>
        <source>user information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="141"/>
        <source>tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="196"/>
        <source>user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="252"/>
        <source>password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="308"/>
        <source>protocol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="351"/>
        <source>server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="382"/>
        <source>directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="411"/>
        <source>SAMBA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="416"/>
        <source>FTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="445"/>
        <source>/</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="476"/>
        <source>port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="508"/>
        <source>20</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="513"/>
        <source>21</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="518"/>
        <source>137</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="523"/>
        <source>138</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="528"/>
        <source>139</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="533"/>
        <source>445</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="592"/>
        <source>ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login-remote-filesystem.ui" line="623"/>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Peony::ComputerViewContainer</name>
    <message>
        <location filename="computer-view-container.cpp" line="111"/>
        <source>Connect a server</source>
        <translation>Připojit k serveru</translation>
    </message>
    <message>
        <source>sftp://, etc...</source>
        <translation type="vanished">sftp://, atd…</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="127"/>
        <source>Unmount</source>
        <translation>Odpojit</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="133"/>
        <source>Eject</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="157"/>
        <source>format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="167"/>
        <location filename="computer-view-container.cpp" line="184"/>
        <source>Property</source>
        <translation>Vlastnost</translation>
    </message>
    <message>
        <location filename="computer-view-container.cpp" line="169"/>
        <source>You have to mount this volume first</source>
        <translation>Tento svazek je třeba nejprve připojit (mount)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="peony-computer-view-plugin.h" line="42"/>
        <source>Computer View</source>
        <translation>Tento počítač</translation>
    </message>
    <message>
        <location filename="peony-computer-view-plugin.h" line="43"/>
        <source>Show drives, network and personal directories.</source>
        <translation>Zobrazit disky, síť a osobní složky.</translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="579"/>
        <source>One or more programs prevented the unmount operation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="580"/>
        <location filename="computer-view/computer-volume-item.cpp" line="584"/>
        <location filename="computer-view/computer-volume-item.cpp" line="588"/>
        <source>Unmount failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="580"/>
        <location filename="computer-view/computer-volume-item.cpp" line="588"/>
        <source>Error: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="583"/>
        <source>Unable to unmount it, you may need to close some programs, such as: GParted etc.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="584"/>
        <source>%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="computer-view/computer-volume-item.cpp" line="611"/>
        <location filename="computer-view/computer-volume-item.cpp" line="626"/>
        <source>Eject failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
